@@ -814,9 +814,12 @@ class Sherlock:
             axs = self.__trim_axs(axs, len(wl))
         flatten_inputs = []
         flattener = Flattener()
+        tmp_lc = lc
         if self.detrend_cores > 1:
             for i in range(0, len(wl)):
                 flatten_inputs.append(FlattenInput(time, lc, wl[i], self.bin_minutes))
+                flatten_result = flattener.flatten_bw(FlattenInput(time, tmp_lc, wl[i], self.bin_minutes))
+                tmp_lc = flatten_result[0]
             if self.detrend_method == 'gp':
                 flatten_results = self.run_multiprocessing(self.run_cores, flattener.flatten_gp, flatten_inputs)
             else:
@@ -829,6 +832,7 @@ class Sherlock:
                 else:
                     flatten_results.append(flattener.flatten_bw(FlattenInput(time, lc, wl[i], self.bin_minutes)))
         i = 0
+        flatten_results[0][0] = tmp_lc
         plot_axs = axs
         for flatten_lc_detrended, lc_trend, bin_centers, bin_means, flatten_wl in flatten_results:
             if self.n_detrends > 1:
